package main

import (
	"testing"

	"gitlab.mashroom.com/mashroom/backend/gmailparser/internal/parser"
)

var zooplaEmail1 = `
Dear team at Emoov National
You have a new
   Buyer enquiry.
BUYER ENQUIRY FROM LISA KARABAS VIA ZPG
Please find below an enquiry from Lisa karabas.
Please respond to this enquiry promptly to maximise your chances of converting this lead.
---
APPLICANT'S DETAILS
Name: lisa karabas
Email address: lisa.karabas@emoov.co.uk
Telephone number: 07967 417061
Type of enquiry: Organise a viewing
Message: Preferred Times:
2018-07-13 08:00 - 12:00
---
Full address: Western Boulevard, Nottingham NG8
Your property ref: 30084_6rk-omm8
http://www.zoopla.co.uk/for-sale/details/48327769
We hope that this lead proves useful to you. If you need to get in touch with
our Customer Service Team, please call us on 020 3544 1000 or email members@zpg.co.uk.
To listen to all your phone calls and view your email enquiries, login to ZooplaPro today:
https://pro.zoopla.co.uk/
---
Search criteria in Lisa karabas's last search:
Lisa karabas searched for properties with the following criteria:
Location: Only interested in UK
Type of property: Houses and flats
---
Copyright 2018 Zoopla Limited. All rights reserved.
Zoopla Limited, The Cooperage, 5 Copper Row, London, SE1 2LH <br> Registered in England and Wales with Company No. 
09005884
`

var zooplaEmail2 = `
You have a new enquiry provided by Zoopla

Please do not reply to this email.
[image: Zoopla]
Tenant enquiry
To view all your leads login to ZooplaPro
<https://www.zoopla.co.uk/ze/tea8ade2505b510227c41f8839532039bffb07cc5635a3=
d000c3fd80042841c517b290fae97972250b6a9e0/?d=3Dhttps%3A%2F%2Fpro.zoopla.co.=
uk%2F&c=3D1625ca016567deae477b041689595bc3>
today.
<https://www.zoopla.co.uk/ze/tea8ade2505b510227c41f8839532039bffb07cc5635a3=
d000c3fd80042841c517b290fae97972250b6a9e0/?d=3Dhttps%3A%2F%2Fpro.zoopla.co.=
uk%2F&c=3D1625ca016567deae477b041689595bc3>
*Dear team at Mashroom*,
You have a new Tenant enquiry
Name: lisa karabas
Telephone: 07967 417061
Email: lisa.karabas@emoov.co.uk
Type of enquiry: Organise a viewing
Unique Reference: listing_95449527_103875
Your property ref: 5de531c124d64d9a52048add
Address: Western Boulevard, Nottingham NG8
[image: 3 bed detached house to rent]
<https://www.zoopla.co.uk/ze/tla8ade2505b510227c41f8839532039bffb07cc5635a3=
d000c3fd80042841c517b290fae97972250b6a9e0/to-rent/details/53829634>
* =C2=A32,250 pcm *   -   *3 bed detached house to rent*
<https://www.zoopla.co.uk/ze/tla8ade2505b510227c41f8839532039bffb07cc5635a3=
d000c3fd80042841c517b290fae97972250b6a9e0/to-rent/details/53829634>
Loxley, Warwick CV35
The Coach House *View more details*
<https://www.zoopla.co.uk/ze/tla8ade2505b510227c41f8839532039bffb07cc5635a3=
d000c3fd80042841c517b290fae97972250b6a9e0/to-rent/details/53829634>
<https://www.zoopla.co.uk/ze/tla8ade2505b510227c41f8839532039bffb07cc5635a3=
d000c3fd80042841c517b290fae97972250b6a9e0/to-rent/details/53829634>
*Location:* Only interested in UK
*Type of property:* Houses and flats
To listen to all your phone calls and view your email enquiries, login to
ZooplaPro
<https://www.zoopla.co.uk/ze/tea8ade2505b510227c41f8839532039bffb07cc5635a3=
d000c3fd80042841c517b290fae97972250b6a9e0/?d=3Dhttps%3A%2F%2Fpro.zoopla.co.=
uk%2F&c=3D1625ca016567deae477b041689595bc3>
today
<https://www.zoopla.co.uk/ze/tea8ade2505b510227c41f8839532039bffb07cc5635a3=
d000c3fd80042841c517b290fae97972250b6a9e0/?d=3Dhttps%3A%2F%2Fpro.zoopla.co.=
uk%2F&c=3D1625ca016567deae477b041689595bc3>
We hope that this information proves useful to you.

Regards,

The Zoopla Team
`

func TestZooplaEmail1(t *testing.T) {
	expected := &parser.EmailFields{
		Name:      "lisa karabas",
		Email:     "lisa.karabas@emoov.co.uk",
		Phone:     "+447967417061",
		Address:   "Western Boulevard, Nottingham NG8",
		Property:  "6rk-omm8",
		Reference: "http://www.zoopla.co.uk/for-sale/details/48327769",
	}

	fields := parseSetZoopla.Parse(zooplaEmail1)

	if fields.Name != expected.Name {
		t.Errorf("Name incorrect, expected '%s', got '%s'", expected.Name, fields.Name)
	}

	if fields.Email != expected.Email {
		t.Errorf("Email incorrect, expected '%s', got '%s'", expected.Email, fields.Email)
	}

	if fields.Phone != expected.Phone {
		t.Errorf("Phone incorrect, expected '%s', got '%s'", expected.Phone, fields.Phone)
	}

	if fields.Address != expected.Address {
		t.Errorf("Address incorrect, expected '%s', got '%s'", expected.Address, fields.Address)
	}

	if fields.Property != expected.Property {
		t.Errorf("RealEstate incorrect, expected '%s', got '%s'", expected.Property, fields.Property)
	}

	if fields.Reference != expected.Reference {
		t.Errorf("Reference incorrect, expected '%s', got '%s'", expected.Reference, fields.Reference)
	}
}

func TestZooplaEmail2(t *testing.T) {
	expected := &parser.EmailFields{
		Name:     "lisa karabas",
		Email:    "lisa.karabas@emoov.co.uk",
		Phone:    "+447967417061",
		Address:  "Western Boulevard, Nottingham NG8",
		Property: "5de531c124d64d9a52048add",
		Reference: "https://www.zoopla.co.uk/ze/" +
			"tla8ade2505b510227c41f8839532039bffb07cc5635a3d000c3fd80042841c517b290fae97972250b6a9e0/" +
			"to-rent/details/53829634",
	}

	fields := parseSetZoopla.Parse(zooplaEmail2)

	if fields.Name != expected.Name {
		t.Errorf("Name incorrect, expected '%s', got '%s'", expected.Name, fields.Name)
	}

	if fields.Email != expected.Email {
		t.Errorf("Email incorrect, expected '%s', got '%s'", expected.Email, fields.Email)
	}

	if fields.Phone != expected.Phone {
		t.Errorf("Phone incorrect, expected '%s', got '%s'", expected.Phone, fields.Phone)
	}

	if fields.Address != expected.Address {
		t.Errorf("Address incorrect, expected '%s', got '%s'", expected.Address, fields.Address)
	}

	if fields.Property != expected.Property {
		t.Errorf("RealEstate incorrect, expected '%s', got '%s'", expected.Property, fields.Property)
	}

	if fields.Reference != expected.Reference {
		t.Errorf("Reference incorrect, expected '%s', got '%s'", expected.Reference, fields.Reference)
	}
}

var rightmoveEmail = `
Rightmove Property Enquiry email
Contact details
---------------
Name: Fake Name
Address: 221 Madeup Way, SW176AW
Email: wibble@emoov.co.uk
Telephone: 0123456789
Your opportunities
------------------
        Wants more details on this property
        Property details
        ----------------
        Description: 1 bed flat for sale
        Address: 71 Melbourne Court, Melbourne Court, Anerley Road, London, SE20, SE20 8AT
        Price: &pound;270,000
        Status: Available
                        Reference: 88484_58d-ony5
                SearchCriteria: Unknown
        Additional comments
        -------------------
        Hi please can I arrange to view this property. Many thanksEsen
Please note!
You MAY NOT pass these details on to any 3rd parties.
This is email no. 14089 sent to you by <a href="https://www.rightmove.co.uk"
style="color:inherit">rightmove.co.uk</a> since 1st January 2018.
`

func TestRightmoveEmail(t *testing.T) {
	expected := &parser.EmailFields{
		Name:      "Fake Name",
		Email:     "wibble@emoov.co.uk",
		Phone:     "+44123456789",
		Address:   "71 Melbourne Court, Melbourne Court, Anerley Road, London, SE20, SE20 8AT",
		Property:  "58d-ony5",
		Reference: "-",
	}

	fields := parseSetRightmove.Parse(rightmoveEmail)

	if fields.Name != expected.Name {
		t.Errorf("Name incorrect, expected '%s', got '%s'", expected.Name, fields.Name)
	}

	if fields.Email != expected.Email {
		t.Errorf("Email incorrect, expected '%s', got '%s'", expected.Email, fields.Email)
	}

	if fields.Phone != expected.Phone {
		t.Errorf("Phone incorrect, expected '%s', got '%s'", expected.Phone, fields.Phone)
	}

	if fields.Address != expected.Address {
		t.Errorf("Address incorrect, expected '%s', got '%s'", expected.Address, fields.Address)
	}

	if fields.Property != expected.Property {
		t.Errorf("RealEstate incorrect, expected '%s', got '%s'", expected.Property, fields.Property)
	}

	if fields.Reference != expected.Reference {
		t.Errorf("Reference incorrect, expected '%s', got '%s'", expected.Reference, fields.Reference)
	}
}
