// Package postgres provides repository implementation for postgresql database
package postgres

import (
	"context"
	"fmt"

	"github.com/golang-migrate/migrate/v4"
	"github.com/golang-migrate/migrate/v4/database/postgres"
	"github.com/jmoiron/sqlx"

	"gitlab.mashroom.com/mashroom/backend/common/generic/log"

	"gitlab.mashroom.com/mashroom/backend/gmailparser/internal/model"
	"gitlab.mashroom.com/mashroom/backend/gmailparser/internal/model/postgres/migrations"
)

type repositoryImpl struct {
	DB *sqlx.DB
	*repositoryImplEnquiry
}

// NewRepository returns new postgresql repository
func NewRepository(db *sqlx.DB) (repository model.Repository, err error) {
	repo := &repositoryImpl{
		DB: db,
	}

	return repo, nil
}

func prepareNamed(db *sqlx.DB, s string) (r *sqlx.NamedStmt, err error) {
	r, err = db.PrepareNamed(s)

	if err != nil {
		fmt.Printf("error %v preparing %s\n", err, s)
	}

	return
}

func (repo *repositoryImpl) prepare() (err error) {
	repo.repositoryImplEnquiry, err = prepareEnquiry(repo.DB)
	if err != nil {
		return
	}

	return nil
}

func (repo *repositoryImpl) Migrate(ctx context.Context) error {
	source, err := migrations.NewSource()
	if err != nil {
		return err
	}

	driver, err := postgres.WithInstance(repo.DB.DB, &postgres.Config{})
	if err != nil {
		return err
	}

	m, err := migrate.NewWithInstance("httpfs", source, "postgres", driver)
	if err != nil {
		return err
	}

	err = m.Up()

	switch {
	case err == nil:
		log.Debug("Migrated.")
	case err == migrate.ErrNoChange:
		log.Debug("Migration not required.")
	default:
		return err
	}

	return repo.prepare()
}
