package postgres

import (
	"context"

	"gitlab.mashroom.com/mashroom/backend/common/api/generic/query"
	"gitlab.mashroom.com/mashroom/backend/common/generic/psqlquery"

	"github.com/jmoiron/sqlx"
	"gitlab.mashroom.com/mashroom/backend/gmailparser/internal/model"
)

type repositoryImplEnquiry struct {
	db   *sqlx.DB
	save *sqlx.NamedStmt
}

func prepareEnquiry(db *sqlx.DB) (r *repositoryImplEnquiry, err error) {
	r = &repositoryImplEnquiry{
		db: db,
	}

	r.save, err = prepareNamed(db, queryEnquirySave)
	if err != nil {
		return
	}

	return
}

const queryEnquirySave = `
insert into enquiries (
  property_id,
  listing_id,
  created_at,
  updated_at
) values (
  :property_id,
  :listing_id,
  now(),
  now()
) on conflict (property_id, listing_id) do update set
  updated_at = now()
`

func (r *repositoryImplEnquiry) EnquirySave(
	ctx context.Context,
	m *model.Enquiry,
) error {
	_, err := r.save.ExecContext(ctx, m)

	return err
}

func (r *repositoryImplEnquiry) EnquiryCount(
	ctx context.Context,
	params *query.QueryParams,
) (count int64, err error) {
	filter, args, err := psqlquery.BuildCountQuery(model.Enquiry{}, "enquiries", params)
	if err != nil {
		return 0, err
	}

	err = r.db.GetContext(ctx, &count, filter, args...)

	return
}
