//go:build func
// +build func

package parser

import (
	"context"
	"flag"
	"os"
	"regexp"
	"strings"
	"testing"

	"cloud.google.com/go/pubsub"
	admin "google.golang.org/api/admin/directory/v1"
	"google.golang.org/api/gmail/v1"
	"google.golang.org/api/option"
)

func ensureFunc(t *testing.T) {
	if m := flag.Lookup("test.run").Value.String(); m == "" || !regexp.MustCompile(m).MatchString(t.Name()) {
		t.Skip("skipping as execution was not requested explicitly using go test -run")
	}
}

func TestFuncSubscriptionClient(t *testing.T) {
	ensureFunc(t)
	os.Setenv("G_RIGHTMOVE", "notifications/rightmove=projects/mashroom-email-listener/topics/portals=rightmove")

	EnvLabels = map[string]*NotificationConfig{}
	EnvHandlers = map[string]*NotificationConfig{}
	readSubscriptionsFromEnv()

	ctx := context.Background()
	EnvServiceKeyFile = "../private.json"

	pubsubsrc, err := serviceAccount(ctx, "", pubsub.ScopePubSub)
	if err != nil {
		t.Error(err)
		return
	}
	psub, err := pubsub.NewClient(ctx, EnvProjectId, option.WithTokenSource(pubsubsrc))
	if err != nil {
		t.Error(err)
		return
	}
	nv := EnvHandlers[idRightmove]
	zooplaSub := psub.Subscription(nv.Subscription)
	zooplaExists, err := zooplaSub.Exists(ctx)
	if err != nil {
		t.Error(err)
		return
	}
	t.Logf("zooplaExists: %v", zooplaExists)
}

func TestFuncGmailClient(t *testing.T) {
	ensureFunc(t)

	ctx := context.Background()
	EnvServiceKeyFile = "../private.json"

	gmailsrc, err := serviceAccount(ctx, EnvSubjectId, admin.AdminDirectoryUserReadonlyScope, admin.AdminDirectoryGroupReadonlyScope, gmail.GmailReadonlyScope, gmail.GmailModifyScope)
	if err != nil {
		t.Error(err)
		return
	}
	gm, err := gmail.NewService(ctx, option.WithTokenSource(gmailsrc))
	if err != nil {
		t.Error(err)
		return
	}

	ls, err := gm.Users.Labels.List("me").Do()
	if err != nil {
		t.Error(err)
		return
	}

	var labels []string
	for _, label := range ls.Labels {
		labels = append(labels, label.Name)
	}
	t.Logf("labels: %v", strings.Join(labels, ", "))
}

//func TestFuncGmailSync(t *testing.T) {
//	ensureFunc(t)
//	os.Setenv("G_RIGHTMOVE", "notifications/rightmove=projects/mashroom-email-listener/topics/testingportals=rightmove-test")
//	//os.Setenv("G_RIGHTMOVE", "notifications/rightmove=projects/mashroom-email-listener/topics/portals=rightmove")
//	//os.Setenv("G_ZOOPLA", "notifications/zoopla=projects/mashroom-email-listener/topics/portals=zoopla")
//
//	EnvSubjectId = "testingportals@mashroom.com"
//	EnvLabels = map[string]*NotificationMap{}
//	EnvHandlers = map[string]*NotificationMap{}
//	readSubscriptionsFromEnv()
//
//	ctx := context.Background()
//	EnvServiceKeyFile = "../private.json"
//
//	defer func() {
//		if err := recover(); err != nil {
//			t.Error(err)
//		}
//	}()
//	GmailSubscribe(context.Background())
//	wg := sync.WaitGroup{}
//	wg.Add(1)
//	GmailSync(ctx)
//	wg.Wait()
//}
