// Package service provides an implementation for gRPC service interface
package service

import (
	"fmt"

	gmailparser "gitlab.mashroom.com/mashroom/backend/gmailparser/api"
	"gitlab.mashroom.com/mashroom/backend/gmailparser/internal/model"
)

// Service contract
type Service interface {
	gmailparser.GmailparserServiceServer
}

// Config for Service
type Config struct {
	Repository model.Repository
}

func validateConfig(config *Config) error {
	if config == nil {
		return fmt.Errorf("invalid service config")
	}

	if config.Repository == nil {
		return fmt.Errorf("no repository in service config")
	}

	return nil
}

// NewService returns new Service instance
func NewService(config *Config) (Service, error) {
	err := validateConfig(config)
	if err != nil {
		return nil, err
	}

	return &serverImpl{
		Config: *config,
	}, nil
}

type serverImpl struct {
	Config
}
