package service

import (
	"context"
	"time"

	"gitlab.mashroom.com/mashroom/backend/common/api/generic/query"

	gmailparser "gitlab.mashroom.com/mashroom/backend/gmailparser/api"
)

func (srv *serverImpl) EnquiryCount(
	ctx context.Context,
	req *gmailparser.EnquiryCountRequest,
) (*gmailparser.EnquiryCountResponse, error) {
	count, err := srv.Repository.EnquiryCount(ctx, req.GetParams())
	if err != nil {
		return nil, err
	}

	return &gmailparser.EnquiryCountResponse{
		Count: count,
	}, nil
}

func (srv *serverImpl) ServiceEnquiryCount(
	ctx context.Context,
	req *gmailparser.ServiceEnquiryCountRequest,
) (*gmailparser.ServiceEnquiryCountResponse, error) {
	counts := make(map[string]int64)

	if req.GetProperties() == nil {
		return &gmailparser.ServiceEnquiryCountResponse{
			Counts: counts,
		}, nil
	}

	after := req.GetProperties().GetAfter().AsTime().Add(1)
	before := req.GetProperties().GetBefore().AsTime().Add(-1)

	for _, p := range req.GetProperties().GetValue() {
		filters := []*query.QueryParamsFilter{
			{
				Fields:   []string{"property_id"},
				Value:    []string{p.GetProperty()},
				Operator: query.QueryFilterOperator_EQUALS,
			},
		}

		if p.GetListing() != "" {
			filters = append(filters, &query.QueryParamsFilter{
				Fields:   []string{"listing_id"},
				Value:    []string{p.GetListing()},
				Operator: query.QueryFilterOperator_EQUALS,
			})
		}

		if after.Unix() > 0 {
			filters = append(filters, &query.QueryParamsFilter{
				Fields:   []string{"created_at"},
				Value:    []string{after.Format(time.RFC3339)},
				Operator: query.QueryFilterOperator_MORE,
			})
		}

		if before.Unix() > 0 {
			filters = append(filters, &query.QueryParamsFilter{
				Fields:   []string{"created_at"},
				Value:    []string{before.Format(time.RFC3339)},
				Operator: query.QueryFilterOperator_LESS,
			})
		}

		count, err := srv.Repository.EnquiryCount(ctx, &query.QueryParams{
			Filter: filters,
		})
		if err != nil {
			return nil, err
		}

		counts[p.GetProperty()] = count
	}

	return &gmailparser.ServiceEnquiryCountResponse{
		Counts: counts,
	}, nil
}
